# LDAP Configuration
#
# Managed by Puppet
#
# Launch ldap backend
launch=ldap

# ldap parameters
ldap-host=<%= @ldap_host %>
ldap-basedn=<%= @ldap_basedn %>
ldap-binddn=<%= @ldap_binddn %>
ldap-secret=<%= @ldap_secret %>
ldap-method=tree


