# PostgreSQL Configuration
#
# Managed by Puppet
#
# Launch gpgsql backend
launch=gpgsql

# gpgsql parameters
gpgsql-host=<%= @host %>
gpgsql-port=<%= @port %>
gpgsql-dbname=<%= @dbname %>
gpgsql-user=<%= @user %>
gpgsql-password=<%= @password %>
gpgsql-dnssec=<%= @dnssec %>
<% if @osfamily == "Redhat" %>
<%= @cfg_include_name %>=<%= @cfg_include_path %>
<% end %>
