# MySQL Configuration
#
# Managed by Puppet
#
# Launch gmysql backend
launch=gmysql

# gmysql parameters
gmysql-host=<%= @host %>
gmysql-port=<%= @port %>
gmysql-dbname=<%= @dbname %>
gmysql-user=<%= @user %>
gmysql-password=<%= @password %>
gmysql-dnssec=<%= @dnssec %>
<% if @osfamily == "Redhat" %>       
<%= @cfg_include_name %>=<%= @cfg_include_path %>
<% end %>

